#!/bin/bash


# this must be run after $package is defined, which is in otsb_set_build_variables
mst_otsb_stow_build_variables () {

	# only set these if the options are present
	otsb_exists_option stowdir && otsb_set stowdir $ots_pkgs
	otsb_exists_option stow-with-destdir && otsb_set stow-with-destdir true

}

otsb_hook_push_back build_variables_after 'mst_otsb_stow_build_variables'

mst_otsb_stow_option_values () {

	# stowing info/dir is a problem, as every package creates it
	stow_opt+=( --ignore info/dir )

}

otsb_hook_push_back options_before 'mst_otsb_stow_option_values'
