#!/bin/bash

if ! command -v mst_otsb_ac_get_latest_archive > /dev/null; then

    mst_otsb_ac_get_latest_archive () {

	local latest="$otsbv_import_root/latest"
	if [ -L "$latest" ]; then

	    local filename=$(readlink "$latest")

	    filename=$(otsb_make_path_absolute "$otsbv_import_root" "$filename")

	    otsbv_set archive "$filename"

	fi

    }
fi
